Enum UnchangedSharedKind
#[non_exhaustive]pub enum UnchangedSharedKind {
ReadOnlyRoot {
version: Version,
digest: Digest,
},
MutateDeleted {
version: Version,
},
ReadDeleted {
version: Version,
},
Cancelled {
version: Version,
},
PerEpochConfig,
}Expand description
Type of unchanged shared object
BCS
The BCS serialized form for this type is defined by the following ABNF:
unchanged-shared-kind = %d00 u64 digest ; ReadOnlyRoot
/ %d01 u64 ; MutateDeleted
/ %d02 u64 ; ReadDeleted
/ %d03 u64 ; Cancelled
/ %d04 ; PerEpochConfigVariants (Non-exhaustive)
This enum is marked as non-exhaustive
ReadOnlyRoot
Read-only shared objects from the input. We don’t really need ObjectDigest for protocol correctness, but it will make it easier to verify untrusted read.
MutateDeleted
Deleted shared objects that appear mutably/owned in the input.
ReadDeleted
Deleted shared objects that appear as read-only in the input.
Cancelled
Shared objects in cancelled transaction. The sequence number embed cancellation reason.
PerEpochConfig
Read of a per-epoch config object that should remain the same during an epoch.
Implementations
pub fn is_read_only_root(&self) -> bool
pub fn is_read_only_root(&self) -> bool
Checks if this is a read_only_root variant.
pub fn is_mutate_deleted(&self) -> bool
pub fn is_mutate_deleted(&self) -> bool
Checks if this is a mutate_deleted variant.
pub fn is_read_deleted(&self) -> bool
pub fn is_read_deleted(&self) -> bool
Checks if this is a read_deleted variant.
pub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Checks if this is a cancelled variant.
pub fn is_per_epoch_config(&self) -> bool
pub fn is_per_epoch_config(&self) -> bool
Checks if this is a per_epoch_config variant.