pub trait TransactionEffectsAPIForTesting: TransactionEffectsAPI {
// Required methods
fn status_mut_for_testing(&mut self) -> &mut ExecutionStatus;
fn gas_cost_summary_mut_for_testing(&mut self) -> &mut GasCostSummary;
fn transaction_digest_mut_for_testing(&mut self) -> &mut TransactionDigest;
fn dependencies_mut_for_testing(&mut self) -> &mut Vec<TransactionDigest> ⓘ;
fn unsafe_add_input_shared_object_for_testing(
&mut self,
kind: InputSharedObject,
);
fn unsafe_add_deleted_live_object_for_testing(
&mut self,
object_ref: ObjectRef,
);
fn unsafe_add_object_tombstone_for_testing(&mut self, object_ref: ObjectRef);
}Expand description
Test-only mutators and unchecked builders for TransactionEffects that
bypass the normal invariants. Not for production use.
Required Methods
Sourcefn status_mut_for_testing(&mut self) -> &mut ExecutionStatus
fn status_mut_for_testing(&mut self) -> &mut ExecutionStatus
Returns a mutable reference to the execution status, for tests.
Sourcefn gas_cost_summary_mut_for_testing(&mut self) -> &mut GasCostSummary
fn gas_cost_summary_mut_for_testing(&mut self) -> &mut GasCostSummary
Returns a mutable reference to the gas cost summary, for tests.
Sourcefn transaction_digest_mut_for_testing(&mut self) -> &mut TransactionDigest
fn transaction_digest_mut_for_testing(&mut self) -> &mut TransactionDigest
Returns a mutable reference to the transaction digest, for tests.
Sourcefn dependencies_mut_for_testing(&mut self) -> &mut Vec<TransactionDigest> ⓘ
fn dependencies_mut_for_testing(&mut self) -> &mut Vec<TransactionDigest> ⓘ
Returns a mutable reference to the dependency list, for tests.
Records kind as an input shared object without validating that it is
consistent with the rest of the effects. For tests only.
Sourcefn unsafe_add_deleted_live_object_for_testing(&mut self, object_ref: ObjectRef)
fn unsafe_add_deleted_live_object_for_testing(&mut self, object_ref: ObjectRef)
Records an entry that represents the pre-execution version of a still live object, without validating consistency with the rest of the effects. For tests only.
Sourcefn unsafe_add_object_tombstone_for_testing(&mut self, object_ref: ObjectRef)
fn unsafe_add_object_tombstone_for_testing(&mut self, object_ref: ObjectRef)
Records a tombstone entry for a deleted object, without validating consistency with the rest of the effects. For tests only.